@@ -1,499 +1,538 @@
 ImportData <- function(parent=NULL) {
   # A GUI for reading table formatted data.
-  
+
   # Additional functions (subroutines)
-  
-  # Read data and fill example data table
-  
-  FillTable <- function(summary.only=TRUE) {
+
+  # Raise error message for bad connection
+
+  RaiseError <- function() {
+    msg <- "Connection to data source failed."
+    tkmessageBox(icon="error", message=msg, title="Error", type="ok", parent=tt)
+  }
+
+  # Raise warning message if data already exists
+
+  RaiseWarning <- function(parent) {
+    if (!is.null(Data("cols"))) {
+      msg <- "This action will delete existing data?"
+      ans <- as.character(tkmessageBox(icon="question", message=msg,
+                                       title="Warning", type="okcancel",
+                                       parent=parent))
+      if (ans == "ok")
+        Data(clear.data=TRUE)
+    }
+  }
+
+  # Read file and populate example table
+
+  ReadFile <- function(summary.only=TRUE) {
     src <- as.character(tclvalue(source.var))
     if (src == "") {
       src <- "clipboard"
       con <- textConnection(cb)
     } else {
       if (substr(src, 1, 6) %in% c("http:/", "ftp://", "file:/")) {
-        con <- try(url(description=src, open="r", encoding=encoding), 
+        con <- try(url(description=src, open="r", encoding=encoding),
                    silent=TRUE)
       } else {
         if (grepl(".gz$", src)) {
-          con <- try(gzfile(description=src, open="r", encoding=encoding, 
+          con <- try(gzfile(description=src, open="r", encoding=encoding,
                             compression=6), silent=TRUE)
         } else {
-          con <- try(file(description=src, open="r", encoding=encoding), 
+          con <- try(file(description=src, open="r", encoding=encoding),
                      silent=TRUE)
         }
       }
     }
-    
+
     if (inherits(con, "try-error") || !isOpen(con, "r")) {
-      msg <- "Could not create a connection to the data source."
-      tkmessageBox(icon="error", message=msg, title="Error", type="ok", 
-                   parent=tt)
+      RaiseError()
       return()
     }
-    
+
     skp <- as.integer(tclvalue(skip.var))
-    if (is.na(skp)) 
+    if (is.na(skp) || skp < 0)
       skp <- 0
-    
+
     nrw <- as.integer(tclvalue(nrow.var))
-    if (is.na(nrw)) 
+    if (is.na(nrw))
       nrw <- -1
-    if (nrw > 0 && nrw < nrows) 
+    if (nrw > 0 && nrw < nrows)
       nrows <- nrw
-    
-    sep <- sep0[as.integer(tcl(frame3.box.1.3, "current")) + 1]
+
+    sep <- sep0[as.integer(tcl(frame3.box.1.1, "current")) + 1]
+    com <- com0[as.integer(tcl(frame3.box.1.3, "current")) + 1]
     nas <- nas0[as.integer(tcl(frame3.box.2.1, "current")) + 1]
     quo <- quo0[as.integer(tcl(frame3.box.2.3, "current")) + 1]
-    com <- com0[as.integer(tcl(frame3.box.2.5, "current")) + 1]
-    
+
     if (summary.only) {
-      tclServiceMode(FALSE)
       d <- try(read.table(con, header=FALSE, sep=sep, quote=quo, row.names=NULL,
-                          na.strings=c("", nas), colClasses="character", 
-                          nrows=nrows, skip=skp, check.names=TRUE, fill=TRUE, 
-                          strip.white=TRUE, blank.lines.skip=TRUE, 
-                          comment.char=com, allowEscapes=TRUE, 
+                          na.strings=c("", nas), colClasses="character",
+                          nrows=nrows, skip=skp, check.names=TRUE, fill=TRUE,
+                          strip.white=TRUE, blank.lines.skip=TRUE,
+                          comment.char=com, allowEscapes=TRUE,
                           flush=TRUE), silent=TRUE)
       close(con)
-      tclServiceMode(TRUE)
-      
       if (inherits(d, "try-error")) {
-        msg <- "There was a problem reading the data source."
-        tkmessageBox(icon="error", message=msg, detail=d, title="Error", 
-                     type="ok", parent=tt)
+        RaiseError()
         return()
       }
-      
+
       # Remove columns containing all NA values
-      
+
       is.all.na <- sapply(seq(along=d), function(i) all(is.na(d[, i])))
       d <- d[, !is.all.na, drop=FALSE]
       return(d)
+
     } else {
-      hds <- as.logical(c(as.integer(tclvalue(names.var)), 
-                          as.integer(tclvalue(units.var)), 
+      hds <- as.logical(c(as.integer(tclvalue(names.var)),
+                          as.integer(tclvalue(units.var)),
                           as.integer(tclvalue(decis.var))))
+
+      RaiseWarning(tt)
+      if (!is.null(Data("cols"))) {
+        close(con)
+        return()
+      }
+
       tkconfigure(tt, cursor="watch")
-      ans <- ReadData(con, headers=hds, sep=sep, quote=quo, nrows=nrw, 
-                      na.strings=c("", nas), skip=skp, comment.char=com, 
-                      parent=tt)
-      close(con)
+      ans <- ReadData(con, headers=hds, sep=sep, quote=quo, nrows=nrw,
+                      na.strings=c("", nas), skip=skp, comment.char=com)
       tkconfigure(tt, cursor="arrow")
-      
+      close(con)
+
+      if (inherits(ans, "try-error")) {
+        RaiseError()
+        return()
+      }
+
       if (!is.null(ans)) {
         Data("headers", hds)
         Data("skip", skp)
         Data("sep", sep)
-        if(nrw < 1) 
-          nrw <- NULL
-        Data("nrows", nrw)
+        Data("nrows", if (nrw < 1) NULL else nrw)
         Data("na.strings", nas)
         Data("quote", quo)
         Data("comment.char", com)
         Data("data.source", src)
-        
         tclvalue(tt.done.var) <- 1
       }
     }
   }
-    
+
   # Rebuild table
-    
+
   RebuildTable <- function() {
-    if (tclvalue(source.var) == "" && is.null(cb)) 
+    if (tclvalue(source.var) == "" && is.null(cb))
       return()
-    
-    d <- FillTable()
-    if (is.null(d)) 
+
+    d <- ReadFile()
+    if (is.null(d))
       return()
-    
+
     tclServiceMode(FALSE)
-    
     ResetGUI()
-    
+
     insert.rows <- nrow(d) - 1 - GetEndRow()
     insert.cols <- ncol(d) - 1 - GetEndCol()
-    
+
     tkconfigure(frame4.tbl, state="normal")
-    
-    if (insert.rows > 0) 
+
+    if (insert.rows > 0)
       tkinsert(frame4.tbl, "rows", "end", insert.rows)
-    if (insert.cols > 0) 
+    if (insert.cols > 0)
       tkinsert(frame4.tbl, "cols", "end", insert.cols)
-    
-    for (i in 1:nrow(d)) {
-      for (j in 1:ncol(d)) 
-        table.var[[i - 1, j - 1]] <- as.tclObj(d[i, j], drop=TRUE)
-    }
-    
+
+    for(j in 1:ncol(d))
+      sapply(1:nrow(d), function(i)
+        table.var[[i - 1, j - 1]] <- as.tclObj(d[i, j], drop=TRUE))
+
     for (i in 1:ncol(d)) {
-      len <- max(nchar(gsub("\t", "    ", d[1:nrows, i])), na.omit=TRUE)
-      if (len < 7) 
+      len <- max(nchar(gsub("\t", "    ", d[1:nrows, i])), na.omit=TRUE) + 3
+      if (len < 7)
         len <- 7
       tcl(frame4.tbl, "width", i - 1, len)
     }
-    
+
     SetTags()
     tkconfigure(frame4.tbl, state="disabled")
     tclServiceMode(TRUE)
   }
-    
+
   # Data file
-  
+
   GetDataFile <- function() {
     exts <- c("txt", "csv", "dat", "gz")
     f <- GetFile(cmd="Open", exts=exts, win.title="Open Data File", parent=tt)
-    if (is.null(f)) 
+    if (is.null(f))
       return()
     tclvalue(source.var) <- f$path
     cb <<- NULL
-    if (f$ext == "csv") 
-      tcl(frame3.box.1.3, "current", match(",", sep0) - 1)
+    if (f$ext == "csv")
+      tcl(frame3.box.1.1, "current", match(",", sep0) - 1)
     RebuildTable()
   }
-  
+
   # Paste clipboard
-  
+
   PasteData <- function() {
     tkselection.set(frame4.tbl, "origin")
-    cb <- try(as.character(tclvalue(tkXselection.get(selection="CLIPBOARD"))), 
+    cb <- try(as.character(tclvalue(tkXselection.get(selection="CLIPBOARD"))),
               silent=TRUE)
     cb <<- if (inherits(cb, "try-error")) NULL else cb
-    if (is.null(cb)) 
+    if (is.null(cb))
       return()
     tclvalue(source.var) <- ""
     RebuildTable()
   }
-  
+
   # Clear all
-  
+
   ClearData <- function() {
     cb <<- NULL
     tclvalue(source.var) <- ""
-    
+
     tclServiceMode(FALSE)
     ResetGUI()
-    tkselection.set(frame4.tbl, "origin")
     tclServiceMode(TRUE)
   }
-  
+
   # Reset GUI
-  
+
   ResetGUI <- function() {
     tkconfigure(frame4.tbl, state="normal")
-    
+
     tcl("unset", table.var)
-    if (GetEndRow() > 0) 
+    if (GetEndRow() > 0)
       tkdelete(frame4.tbl, "rows", 1, GetEndRow())
-    if (GetEndCol() > 0) 
+    if (GetEndCol() > 0)
       tkdelete(frame4.tbl, "cols", 1, GetEndCol())
     tcl(frame4.tbl, "clear", "all")
-    
+
+    tkselection.set(frame4.tbl, "origin")
     tkconfigure(frame4.tbl, state="disabled")
-    
+
     s <- "normal"
-    if (tclvalue(source.var) == "" && is.null(cb)) 
+    if (tclvalue(source.var) == "" && is.null(cb))
       s <- "disabled"
     tkconfigure(frame0.but.1, state=s)
   }
-  
+
   # Set tags in table
-  
+
   SetTags <- function() {
-    if (GetEndRow() == 0 & GetEndCol() == 0) 
+    if (GetEndRow() == 0 & GetEndCol() == 0)
       return()
-    
+
     tcl(frame4.tbl, "clear", "tags")
     tcl(frame4.tbl, "tag", "row", "h1", 0)
     tcl(frame4.tbl, "tag", "row", "h2", 1)
     tcl(frame4.tbl, "tag", "row", "h3", 2)
-    
-    logic <- as.logical(as.integer(c(tclvalue(names.var), tclvalue(units.var), 
+
+    logic <- as.logical(as.integer(c(tclvalue(names.var), tclvalue(units.var),
                                      tclvalue(decis.var))))
     headCol <- c("#FFD0D4", "#FFFEDE", "#EBFFC6")[logic]
-    if (length(headCol) < 3) 
+    if (length(headCol) < 3)
       headCol[(length(headCol) + 1):3] <- "white"
-    
+
     tktag.configure(frame4.tbl, "h1", background=headCol[1])
     tktag.configure(frame4.tbl, "h2", background=headCol[2])
     tktag.configure(frame4.tbl, "h3", background=headCol[3])
   }
-  
+
   # Determine the tables maximum row and column
-  
+
   GetEndRow <- function() as.numeric(tkindex(frame4.tbl, "end", "row"))
   GetEndCol <- function() as.numeric(tkindex(frame4.tbl, "end", "col"))
-  
-  
+
+
   # Main program
-  
-  tclRequire(package="Tktable", warn=TRUE) # require Tktable
-  
+
+  # GUI requires Tktable
+
+  is.tktable <- !inherits(try(tcl("package", "present", "Tktable"),
+                          silent=TRUE), "try-error")
+
+  if (!is.tktable) {
+    f <- GetFile(cmd="Open", exts="txt", win.title="Open Data File",
+                 parent=parent)
+    if (!is.null(f)) {
+      RaiseWarning(parent)
+      if (is.null(Data("cols")))
+        ReadData(f$path)
+    }
+    return()
+  }
+
+  # Initialize values
+
   cb <- NULL
-  
+
   nrows <- 50
-  
+
   sep0 <- c("\t", "", ",", ";", "|")
-  sep1 <- c("Tab ( \\t )", "White space (  )", "Comma ( , )", 
+  sep1 <- c("Tab ( \\t )", "White space (  )", "Comma ( , )",
             "Semicolon ( ; )", "Vertical bar ( | )")
-  
+
   nas0 <- c("NA", "na", "N/A", "n/a")
   nas1 <- c("NA", "na", "N/A", "n/a")
-  
+
   quo0 <- c("", "\"", "'")
-  quo1 <- c("None", "Double ( \" )", "Single ( \' )")
-  
-  com0 <- c("", "#", "!", "\\")
-  com1 <- c("None", "Number sign ( # )", "Exclamation ( ! )", 
-            "Backslash ( \\\\ )")
-  
+  quo1 <- c("", "Double ( \" )", "Single ( \' )")
+
+  com0 <- c("", "#", "!", "\\", "~")
+  com1 <- c("", "Number sign ( # )", "Exclamation ( ! )",
+            "Backslash ( \\\\ )", "Tilde ( ~ )")
+
   encoding <- Data("encoding")
-  
+
   # Assign variables linked to Tk widgets
-  
+
   table.var <- tclArray()
-  
+
   names.var  <- tclVar(0)
   units.var  <- tclVar(0)
   decis.var  <- tclVar(0)
   skip.var   <- tclVar(0)
   nrow.var   <- tclVar()
   source.var <- tclVar()
-  
+
   tt.done.var <- tclVar(0)
-  
+
   # Set header variables
-  
+
   if (!is.null(Data("headers"))) {
     tclvalue(names.var) <- Data("headers")[1]
     tclvalue(units.var) <- Data("headers")[2]
     tclvalue(decis.var) <- Data("headers")[3]
   }
-  
+
   # Open GUI
-  
+
   tclServiceMode(FALSE)
-  
+
   tt <- tktoplevel(padx=0, pady=0)
-  
+
   if (!is.null(parent)) {
     tkwm.transient(tt, parent)
     tmp <- unlist(strsplit(as.character(tkwm.geometry(parent)), "\\+"))
-    tkwm.geometry(tt, paste("+", as.integer(tmp[2]) + 25, 
+    tkwm.geometry(tt, paste("+", as.integer(tmp[2]) + 25,
                             "+", as.integer(tmp[3]) + 25, sep=""))
   }
-  
+
   tktitle(tt) <- "Import File"
-  
+
   # Frame 0 contains load and cancel buttons, and size grip
-  
+
   frame0 <- ttkframe(tt, relief="flat")
-  
-  frame0.but.1 <- ttkbutton(frame0, width=12, text="Load", 
-                            command=function() FillTable(FALSE))
-  frame0.but.2 <- ttkbutton(frame0, width=12, text="Cancel", 
+
+  frame0.but.1 <- ttkbutton(frame0, width=12, text="Load",
+                            command=function() ReadFile(FALSE))
+  frame0.but.2 <- ttkbutton(frame0, width=12, text="Cancel",
                             command=function() tclvalue(tt.done.var) <- 1)
-  
+
   frame0.grp.3 <- ttksizegrip(frame0)
-  
+
   tkgrid(frame0.but.1, frame0.but.2, frame0.grp.3)
-  
+
   tkgrid.configure(frame0.but.1, sticky="e", padx=2, pady=8)
   tkgrid.configure(frame0.but.2, sticky="w", padx=2, pady=8, rowspan=2)
   tkgrid.configure(frame0.grp.3, sticky="se")
-  
+
   tkpack(frame0, side="bottom", anchor="e")
-  
+
   tkconfigure(frame0.but.1, state="disabled")
-  
+
   # Frame 1 contains file locator
-  
+
   frame1 <- ttkframe(tt, relief="flat", padding=0, borderwidth=0)
-  
+
   frame1.lab.1 <- ttklabel(frame1, text="Import data from")
   txt <- paste("    or transfer data from clipboard via a copy and paste",
                "operation.")
   frame1.lab.2 <- ttklabel(frame1, text=txt)
-  
+
   frame1.ent.1 <- ttkentry(frame1, textvariable=source.var)
-  frame1.but.1 <- ttkbutton(frame1, width=8, text="Browse", 
+  frame1.but.1 <- ttkbutton(frame1, width=8, text="Browse",
                             command=GetDataFile)
-  
+
   tkgrid(frame1.lab.1, frame1.ent.1, frame1.but.1, pady=c(10, 0))
   tkgrid(frame1.lab.2, "x", "x", pady=c(5, 0))
-  
+
   tkgrid.configure(frame1.lab.1, sticky="w")
   tkgrid.configure(frame1.ent.1, sticky="we", padx=2)
-  
+
   tkgrid.configure(frame1.lab.2, columnspan=3, sticky="w")
-  
+
   tkgrid.columnconfigure(frame1, 1, weight=1)
-  
+
   tkpack(frame1, fill="x", anchor="w", padx=10)
-  
+
   tkbind(frame1.ent.1, "<Return>", RebuildTable)
-  
+
   # Frame 2 contains header line information
-  
-  frame2 <- ttklabelframe(tt, relief="flat", borderwidth=5, padding=5, 
+
+  frame2 <- ttklabelframe(tt, relief="flat", borderwidth=5, padding=5,
                           text="Identify header lines")
-  
-  txt <- "names, short descriptive names for data in each column."
-  frame2.chk.1.1 <- ttkcheckbutton(frame2, variable=names.var, 
+
+  txt <- "Names, short descriptive names for data in each column."
+  frame2.chk.1.1 <- ttkcheckbutton(frame2, variable=names.var,
                                    command=SetTags, text=txt)
-  txt <- "units, measurement units associated with values in each column."
-  frame2.chk.2.1 <- ttkcheckbutton(frame2, variable=units.var, 
+  txt <- "Units, measurement units associated with values in each column."
+  frame2.chk.2.1 <- ttkcheckbutton(frame2, variable=units.var,
                                    command=SetTags, text=txt)
-  txt <- paste("precision, number of decimal places used to",
+  txt <- paste("Precision, number of decimal places used to",
                "express data in each column.")
-  frame2.chk.3.1 <- ttkcheckbutton(frame2, variable=decis.var, 
+  frame2.chk.3.1 <- ttkcheckbutton(frame2, variable=decis.var,
                                    command=SetTags, text=txt)
-  
+
   tkgrid(frame2.chk.1.1, pady=1, sticky="w")
   tkgrid(frame2.chk.2.1, pady=1, sticky="w")
   tkgrid(frame2.chk.3.1, pady=1, sticky="w")
-  
+
   tkpack(frame2, anchor="w", fill="x", padx=10, pady=10)
-  
+
   # Frame 3 contains import parameters
-  
-  frame3 <- ttklabelframe(tt, relief="flat", borderwidth=5, padding=5, 
+
+  frame3 <- ttklabelframe(tt, relief="flat", borderwidth=5, padding=5,
                           text="Select import parameters")
-  
-  frame3.ent.1.1 <- ttkentry(frame3, width=17, textvariable=skip.var)
-  frame3.ent.1.5 <- ttkentry(frame3, width=17, textvariable=nrow.var)
-  
-  tkbind(frame3.ent.1.1, "<KeyRelease>", 
+
+  frame3.lab.1.2 <- ttklabel(frame3, width=10, text="seperator")
+  frame3.lab.1.4 <- ttklabel(frame3, width=10, text="comment")
+  frame3.lab.1.6 <- ttklabel(frame3, width= 8, text="skip lines")
+  frame3.lab.2.2 <- ttklabel(frame3, width=10, text="NA strings")
+  frame3.lab.2.4 <- ttklabel(frame3, width=10, text="quote")
+  frame3.lab.2.6 <- ttklabel(frame3, width= 8, text="max lines")
+
+  frame3.box.1.1 <- ttkcombobox(frame3, width=14, state="readonly", value=sep1)
+  frame3.box.1.3 <- ttkcombobox(frame3, width=14, state="readonly", value=com1)
+  frame3.box.2.1 <- ttkcombobox(frame3, width=14, state="readonly", value=nas1)
+  frame3.box.2.3 <- ttkcombobox(frame3, width=14, state="readonly", value=quo1)
+
+  tkbind(frame3.box.1.1, "<<ComboboxSelected>>", RebuildTable)
+  tkbind(frame3.box.1.3, "<<ComboboxSelected>>", RebuildTable)
+  tkbind(frame3.box.2.1, "<<ComboboxSelected>>", RebuildTable)
+  tkbind(frame3.box.2.3, "<<ComboboxSelected>>", RebuildTable)
+
+  frame3.ent.1.5 <- ttkentry(frame3, width=14, textvariable=skip.var)
+  frame3.ent.2.5 <- ttkentry(frame3, width=14, textvariable=nrow.var)
+
+  tkbind(frame3.ent.1.5, "<KeyRelease>",
          function() {
            tclvalue(skip.var) <- CheckEntry("integer", tclvalue(skip.var))
            RebuildTable()
          }
   )
-  tkbind(frame3.ent.1.5, "<KeyRelease>", 
+  tkbind(frame3.ent.2.5, "<KeyRelease>",
          function() {
            tclvalue(nrow.var) <- CheckEntry("integer", tclvalue(nrow.var))
            RebuildTable()
          }
   )
-  
-  frame3.lab.1.2 <- ttklabel(frame3, width=10, text="skip lines")
-  frame3.lab.1.4 <- ttklabel(frame3, width=10, text="seperator")
-  frame3.lab.1.6 <- ttklabel(frame3, width= 8, text="max rows")
-  frame3.lab.2.2 <- ttklabel(frame3, width=10, text="NA strings")
-  frame3.lab.2.4 <- ttklabel(frame3, width=10, text="quote")
-  frame3.lab.2.6 <- ttklabel(frame3, width= 8, text="comment")
-  
-  frame3.box.1.3 <- ttkcombobox(frame3, width=14, state="readonly", value=sep1)
-  frame3.box.2.1 <- ttkcombobox(frame3, width=14, state="readonly", value=nas1)
-  frame3.box.2.3 <- ttkcombobox(frame3, width=14, state="readonly", value=quo1)
-  frame3.box.2.5 <- ttkcombobox(frame3, width=14, state="readonly", value=com1)
-  
-  tkbind(frame3.box.1.3, "<<ComboboxSelected>>", RebuildTable)
-  tkbind(frame3.box.2.1, "<<ComboboxSelected>>", RebuildTable)
-  tkbind(frame3.box.2.3, "<<ComboboxSelected>>", RebuildTable)
-  tkbind(frame3.box.2.5, "<<ComboboxSelected>>", RebuildTable)
-  
-  tkgrid(frame3.ent.1.1, frame3.lab.1.2, frame3.box.1.3, frame3.lab.1.4, 
+
+  tkgrid(frame3.box.1.1, frame3.lab.1.2, frame3.box.1.3, frame3.lab.1.4,
          frame3.ent.1.5, frame3.lab.1.6)
-  tkgrid(frame3.box.2.1, frame3.lab.2.2, frame3.box.2.3, frame3.lab.2.4, 
-         frame3.box.2.5, frame3.lab.2.6, pady=c(5, 0))
-  
-  tkgrid.configure(frame3.lab.1.2, frame3.lab.1.4, frame3.lab.1.6, 
-                   frame3.lab.2.2, frame3.lab.2.4, frame3.lab.2.6, 
-                   padx=2, sticky="w")
-  
+  tkgrid(frame3.box.2.1, frame3.lab.2.2, frame3.box.2.3, frame3.lab.2.4,
+         frame3.ent.2.5, frame3.lab.2.6, pady=c(5, 0))
+
+  tkgrid.configure(frame3.lab.1.2, frame3.lab.1.4, frame3.lab.2.2,
+                   frame3.lab.2.4, padx=2, sticky="w")
+
+  tkgrid.configure(frame3.lab.1.6, frame3.lab.2.6, padx=c(2, 0), sticky="w")
+
   tkpack(frame3, anchor="w", fill="x", padx=10, pady=c(0, 15))
-  
+
+  tcl(frame3.box.1.1, "current", 0)
   tcl(frame3.box.1.3, "current", 0)
   tcl(frame3.box.2.1, "current", 0)
   tcl(frame3.box.2.3, "current", 0)
-  tcl(frame3.box.2.5, "current", 0)
-  
-  if (!is.null(Data("skip"))) 
+
+  if (!is.null(Data("skip")))
     tclvalue(skip.var) <- Data("skip")
-  if (!is.null(Data("nrows"))) 
+  if (!is.null(Data("nrows")))
     tclvalue(nrow.var) <- Data("nrows")
-  
-  if (!is.null(Data("sep"))) 
-    tcl(frame3.box.1.3, "current", match(Data("sep"), sep0) - 1)
-  if (!is.null(Data("na.strings"))) 
+
+  if (!is.null(Data("sep")))
+    tcl(frame3.box.1.1, "current", match(Data("sep"), sep0) - 1)
+  if (!is.null(Data("comment.char")))
+    tcl(frame3.box.1.3, "current", match(Data("comment.char"), com0) - 1)
+  if (!is.null(Data("na.strings")))
     tcl(frame3.box.2.1, "current", match(Data("na.strings"), nas0) - 1)
-  if (!is.null(Data("quote"))) 
+  if (!is.null(Data("quote")))
     tcl(frame3.box.2.3, "current", match(Data("quote"), quo0) - 1)
-  if (!is.null(Data("comment.char"))) 
-    tcl(frame3.box.2.5, "current", match(Data("comment.char"), com0) - 1)
-  
+
   # Frame 4 contains example data table
-  
+
   frame4 <- ttkframe(tt, relief="flat", padding=0, borderwidth=0)
-  
+
   .Tcl("option add *Table.font {CourierNew 9}")
-  frame4.tbl <- tkwidget(frame4, "table", rows=1, cols=1, variable=table.var, 
-                         state="disabled", colwidth=13, rowheight=1, width=1, 
-                         height=1, ipadx=3, ipady=1, wrap=0, 
-                         highlightcolor="gray75", background="white", 
-                         foreground="black", titlerows=0, titlecols=0, 
-                         multiline=0, resizeborders="col", 
-                         colstretchmode="none", rowstretchmode="none", 
-                         anchor="nw", drawmode="fast", rowseparator="\n", 
-                         colseparator="\t", selectmode="extended", 
-                         insertofftime=0, 
-                         xscrollcommand=function(...) tkset(frame4.xsc,...), 
+  frame4.tbl <- tkwidget(frame4, "table", rows=1, cols=1, variable=table.var,
+                         state="disabled", colwidth=13, rowheight=1, width=1,
+                         height=1, ipadx=3, ipady=1, wrap=0,
+                         highlightcolor="gray75", background="white",
+                         foreground="black", titlerows=0, titlecols=0,
+                         multiline=0, resizeborders="col",
+                         colstretchmode="none", rowstretchmode="none",
+                         anchor="nw", drawmode="single", rowseparator="\n",
+                         colseparator="\t", selectmode="extended",
+                         insertofftime=0,
+                         xscrollcommand=function(...) tkset(frame4.xsc,...),
                          yscrollcommand=function(...) tkset(frame4.ysc,...))
-  
-  frame4.xsc <- tkscrollbar(frame4, orient="horizontal", 
+
+  frame4.xsc <- tkscrollbar(frame4, orient="horizontal",
                             command=function(...) tkxview(frame4.tbl,...))
-  frame4.ysc <- tkscrollbar(frame4, orient="vertical", 
+  frame4.ysc <- tkscrollbar(frame4, orient="vertical",
                             command=function(...) tkyview(frame4.tbl,...))
-  
+
   tkgrid(frame4.tbl, frame4.ysc)
   tkgrid(frame4.xsc, "x")
-  
+
   tkgrid.configure(frame4.tbl, sticky="news", padx=c(10, 0), pady=0)
   tkgrid.configure(frame4.ysc, sticky="ns", padx=c(0, 10), pady=c(1, 0))
   tkgrid.configure(frame4.xsc, sticky="we", padx=c(11, 0), pady=0)
-  
+
   tktag.configure(frame4.tbl, "active", background="#EAEEFE", relief="")
   tktag.configure(frame4.tbl, "sel", background="#EAEEFE")
-  
+
   tkconfigure(frame4.tbl, borderwidth=0, highlightthickness=0)
-  
+
   tkgrid.columnconfigure(frame4, 0, weight=1)
   tkgrid.rowconfigure(frame4, 0, weight=1)
-  
+
   tkpack(frame4, fill="both", expand=TRUE)
-  
+
   tkbind(frame4.tbl, "<<Paste>>", PasteData)
-  
+
+  tkselection.set(frame4.tbl, "origin")
+
   # Frame 5 contians paste and clear buttons
-  
+
   frame5 <- ttkframe(tt, relief="flat", padding=0, borderwidth=0)
-  
-  frame5.but.1 <- ttkbutton(frame5, width=12, text="Paste", 
+
+  frame5.but.1 <- ttkbutton(frame5, width=12, text="Paste",
                             command=PasteData)
-  frame5.but.2 <- ttkbutton(frame5, width=12, text="Clear", 
+  frame5.but.2 <- ttkbutton(frame5, width=12, text="Clear",
                             command=ClearData)
-  
+
   tkgrid(frame5.but.1, frame5.but.2, padx=2, pady=c(5, 0))
-  
+
   tkpack(frame5, anchor="w", padx=9)
-  
+
   # GUI control
-  
+
   RebuildTable()
-  
+
   tkgrab(tt)
   tkbind(tt, "<Destroy>", function() tclvalue(tt.done.var) <- 1)
-  
+
   tclServiceMode(TRUE)
   tkfocus(tt)
   tkwait.variable(tt.done.var)
-  
+
   tclServiceMode(FALSE)
   tkgrab.release(tt)
   tkdestroy(tt)
   tclServiceMode(TRUE)
-  
+
   invisible()
 }
