@@ -1,36 +1,36 @@
 SetConfiguration <- function(parent=NULL) {
   # A GUI for specifying window geometry and universal plotting parameters.
-  
+
   # Additional functions (subroutines)
-  
+
   UpdatePar <- function() {
     tmp <- as.integer(tclvalue(nlevels.var))
     Data("nlevels", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(width.var))
     Data("width", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(cex.pts.var))
     Data("cex.pts", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(asp.yx.var))
     Data("asp.yx", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(asp.zx.var))
     Data("asp.zx", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(vmax.var))
     Data("vmax", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(vxby.var))
     Data("vxby", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.numeric(tclvalue(vyby.var))
     Data("vyby", if (is.na(tmp)) NULL else tmp)
-    
+
     tmp <- as.integer(tclvalue(tgap.var))
     Data("tgap", if (is.na(tmp)) NULL else tmp)
-    
+
     Data("rkey", as.integer(tclvalue(rkey.var)))
     Data("img.contour", as.integer(tclvalue(img.contour.var)))
     Data("show.arrows", as.integer(tclvalue(show.arrows.var)))
@@ -41,14 +41,14 @@ SetConfiguration <- function(parent=NULL) {
     Data("show.2.axes", as.integer(tclvalue(show.2.axes.var)))
     Data("minor.ticks", as.integer(tclvalue(minor.ticks.var)))
     Data("ticks.inside", as.integer(tclvalue(ticks.inside.var)))
-    
+
     tclvalue(tt.done.var) <- 1
   }
-  
+
   # Main program
-  
+
   # Assign variables linked to Tk widgets
-  
+
   nlevels.var      <- tclVar()
   width.var        <- tclVar()
   cex.pts.var      <- tclVar()
@@ -68,87 +68,87 @@ SetConfiguration <- function(parent=NULL) {
   show.2.axes.var  <- tclVar()
   minor.ticks.var  <- tclVar()
   ticks.inside.var <- tclVar()
-  
-  if (!is.null(Data("nlevels"))) 
+
+  if (!is.null(Data("nlevels")))
     tclvalue(nlevels.var) <- Data("nlevels")
-  if (!is.null(Data("width"))) 
+  if (!is.null(Data("width")))
     tclvalue(width.var) <- Data("width")
-  if (!is.null(Data("cex.pts"))) 
+  if (!is.null(Data("cex.pts")))
     tclvalue(cex.pts.var) <- Data("cex.pts")
-  if (!is.null(Data("asp.yx"))) 
+  if (!is.null(Data("asp.yx")))
     tclvalue(asp.yx.var) <- Data("asp.yx")
-  if (!is.null(Data("asp.zx"))) 
+  if (!is.null(Data("asp.zx")))
     tclvalue(asp.zx.var) <- Data("asp.zx")
-  if (!is.null(Data("vmax"))) 
+  if (!is.null(Data("vmax")))
     tclvalue(vmax.var) <- Data("vmax")
-  if (!is.null(Data("vxby"))) 
+  if (!is.null(Data("vxby")))
     tclvalue(vxby.var) <- Data("vxby")
   if (!is.null(Data("vyby")))
     tclvalue(vyby.var) <- Data("vyby")
-  if (!is.null(Data("tgap"))) 
+  if (!is.null(Data("tgap")))
     tclvalue(tgap.var) <- Data("tgap")
-  if (!is.null(Data("rkey"))) 
+  if (!is.null(Data("rkey")))
     tclvalue(rkey.var) <- Data("rkey")
-  if (!is.null(Data("show.poly"))) 
+  if (!is.null(Data("show.poly")))
     tclvalue(show.poly.var) <- Data("show.poly")
-  if (!is.null(Data("img.contour"))) 
+  if (!is.null(Data("img.contour")))
     tclvalue(img.contour.var) <- Data("img.contour")
-  if (!is.null(Data("show.lines"))) 
+  if (!is.null(Data("show.lines")))
     tclvalue(show.lines.var) <- Data("show.lines")
-  if (!is.null(Data("show.points"))) 
+  if (!is.null(Data("show.points")))
     tclvalue(show.points.var) <- Data("show.points")
-  if (!is.null(Data("show.arrows"))) 
+  if (!is.null(Data("show.arrows")))
     tclvalue(show.arrows.var) <- Data("show.arrows")
-  if (!is.null(Data("vuni"))) 
+  if (!is.null(Data("vuni")))
     tclvalue(vuni.var) <- Data("vuni")
-  if (!is.null(Data("show.2.axes"))) 
+  if (!is.null(Data("show.2.axes")))
     tclvalue(show.2.axes.var) <- Data("show.2.axes")
-  if (!is.null(Data("minor.ticks"))) 
+  if (!is.null(Data("minor.ticks")))
     tclvalue(minor.ticks.var) <- Data("minor.ticks")
-  if (!is.null(Data("ticks.inside"))) 
+  if (!is.null(Data("ticks.inside")))
     tclvalue(ticks.inside.var) <- Data("ticks.inside")
-  
+
   tt.done.var <- tclVar(0)
-  
+
   # Open GUI
-  
+
   tclServiceMode(FALSE)
   tt <- tktoplevel(padx=0, pady=0)
   if (!is.null(parent)) {
     tkwm.transient(tt, parent)
     tmp <- unlist(strsplit(as.character(tkwm.geometry(parent)), "\\+"))
-    tkwm.geometry(tt, paste("+", as.integer(tmp[2]) + 25, 
+    tkwm.geometry(tt, paste("+", as.integer(tmp[2]) + 25,
                             "+", as.integer(tmp[3]) + 25, sep=""))
   }
   tktitle(tt) <- "Configuration"
-  
+
   tkwm.resizable(tt, 1, 0)
-  
+
   # Frame 0 contains ok and cancel buttons
-  
+
   frame0 <- ttkframe(tt, relief="flat")
-  
-  frame0.but.1 <- ttkbutton(frame0, width=12, text="OK", 
+
+  frame0.but.1 <- ttkbutton(frame0, width=12, text="OK",
                             command=UpdatePar)
-  frame0.but.2 <- ttkbutton(frame0, width=12, text="Cancel", 
+  frame0.but.2 <- ttkbutton(frame0, width=12, text="Cancel",
                             command=function() tclvalue(tt.done.var) <- 1)
-  
+
   tkgrid(frame0.but.1, frame0.but.2)
-  
+
   tkgrid.configure(frame0.but.1, sticky="e", padx=c(4,0), pady=c(5,8))
-  tkgrid.configure(frame0.but.2, sticky="w", padx=c(4,8), pady=c(5,8), 
+  tkgrid.configure(frame0.but.2, sticky="w", padx=c(4,8), pady=c(5,8),
                    rowspan=2)
-  
+
   tkpack(frame0, side="bottom", anchor="e")
-  
+
   # Paned window
-  
+
   pw <- ttkpanedwindow(tt, orient="horizontal")
-  
+
   # Frame 1 contains parameters
-  
+
   frame1 <- ttkframe(pw, relief="flat", borderwidth=5, padding=8)
-  
+
   txt <- "Approximate number of contour levels"
   frame1.lab.1.1 <- ttklabel(frame1, text=txt)
   txt <- "Width of plotting window canvas (in)"
@@ -167,7 +167,7 @@ SetConfiguration <- function(parent=NULL) {
   frame1.lab.8.1 <- ttklabel(frame1, text=txt)
   txt <- "Time gap exceedence level (sec)"
   frame1.lab.9.1 <- ttklabel(frame1, text=txt)
-  
+
   frame1.ent.1.2 <- ttkentry(frame1, width=8, textvariable=nlevels.var)
   frame1.ent.2.2 <- ttkentry(frame1, width=8, textvariable=width.var)
   frame1.ent.3.2 <- ttkentry(frame1, width=8, textvariable=cex.pts.var)
@@ -177,44 +177,44 @@ SetConfiguration <- function(parent=NULL) {
   frame1.ent.7.2 <- ttkentry(frame1, width=8, textvariable=vxby.var)
   frame1.ent.8.2 <- ttkentry(frame1, width=8, textvariable=vyby.var)
   frame1.ent.9.2 <- ttkentry(frame1, width=8, textvariable=tgap.var)
-  
-  tkbind(frame1.ent.1.2, "<KeyRelease>", 
+
+  tkbind(frame1.ent.1.2, "<KeyRelease>",
          function() {
            tclvalue(nlevels.var) <- CheckEntry("integer", tclvalue(nlevels.var))
          })
-  tkbind(frame1.ent.2.2, "<KeyRelease>", 
+  tkbind(frame1.ent.2.2, "<KeyRelease>",
          function() {
            tclvalue(width.var) <- CheckEntry("numeric", tclvalue(width.var))
          })
-  tkbind(frame1.ent.3.2, "<KeyRelease>", 
+  tkbind(frame1.ent.3.2, "<KeyRelease>",
          function() {
            tclvalue(cex.pts.var) <- CheckEntry("numeric", tclvalue(cex.pts.var))
          })
-  tkbind(frame1.ent.4.2, "<KeyRelease>", 
+  tkbind(frame1.ent.4.2, "<KeyRelease>",
          function() {
            tclvalue(asp.yx.var) <- CheckEntry("numeric", tclvalue(asp.yx.var))
          })
-  tkbind(frame1.ent.5.2, "<KeyRelease>", 
+  tkbind(frame1.ent.5.2, "<KeyRelease>",
          function() {
            tclvalue(asp.zx.var) <- CheckEntry("numeric", tclvalue(asp.zx.var))
          })
-  tkbind(frame1.ent.6.2, "<KeyRelease>", 
+  tkbind(frame1.ent.6.2, "<KeyRelease>",
          function() {
            tclvalue(vmax.var) <- CheckEntry("numeric", tclvalue(vmax.var))
          })
-  tkbind(frame1.ent.7.2, "<KeyRelease>", 
+  tkbind(frame1.ent.7.2, "<KeyRelease>",
          function() {
            tclvalue(vxby.var) <- CheckEntry("integer", tclvalue(vxby.var))
          })
-  tkbind(frame1.ent.8.2, "<KeyRelease>", 
+  tkbind(frame1.ent.8.2, "<KeyRelease>",
          function() {
            tclvalue(vyby.var) <- CheckEntry("integer", tclvalue(vyby.var))
          })
-  tkbind(frame1.ent.9.2, "<KeyRelease>", 
+  tkbind(frame1.ent.9.2, "<KeyRelease>",
          function() {
            tclvalue(tgap.var) <- CheckEntry("numeric", tclvalue(tgap.var))
          })
-  
+
   tkgrid(frame1.lab.1.1, frame1.ent.1.2, padx=1, pady=1)
   tkgrid(frame1.lab.2.1, frame1.ent.2.2, padx=1, pady=1)
   tkgrid(frame1.lab.3.1, frame1.ent.3.2, padx=1, pady=1)
@@ -224,20 +224,20 @@ SetConfiguration <- function(parent=NULL) {
   tkgrid(frame1.lab.7.1, frame1.ent.7.2, padx=1, pady=1)
   tkgrid(frame1.lab.8.1, frame1.ent.8.2, padx=1, pady=1)
   tkgrid(frame1.lab.9.1, frame1.ent.9.2, padx=1, pady=1)
-  
-  tkgrid.configure(frame1.lab.1.1, frame1.lab.2.1, frame1.lab.3.1, 
-                   frame1.lab.4.1, frame1.lab.5.1, frame1.lab.6.1, 
+
+  tkgrid.configure(frame1.lab.1.1, frame1.lab.2.1, frame1.lab.3.1,
+                   frame1.lab.4.1, frame1.lab.5.1, frame1.lab.6.1,
                    frame1.lab.7.1, frame1.lab.8.1, frame1.lab.9.1, sticky="e")
-  tkgrid.configure(frame1.ent.1.2, frame1.ent.2.2, frame1.ent.3.2, 
-                   frame1.ent.4.2, frame1.ent.5.2, frame1.ent.6.2, 
+  tkgrid.configure(frame1.ent.1.2, frame1.ent.2.2, frame1.ent.3.2,
+                   frame1.ent.4.2, frame1.ent.5.2, frame1.ent.6.2,
                    frame1.ent.7.2, frame1.ent.8.2, frame1.ent.9.2, sticky="we")
-  
+
   tkgrid.columnconfigure(frame1, 1, weight=1, minsize=6)
-  
+
   # Frame 2 contains plot features
-  
+
   frame2 <- ttkframe(pw, relief="flat", borderwidth=5, padding=8)
-  
+
   txt <- "reverse legend"
   frame2.chk.01.1 <- ttkcheckbutton(frame2, text=txt, variable=rkey.var)
   txt <- "show polygons"
@@ -248,18 +248,18 @@ SetConfiguration <- function(parent=NULL) {
   frame2.chk.04.1 <- ttkcheckbutton(frame2, text=txt, variable=show.lines.var)
   txt <- "show points on surface"
   frame2.chk.05.1 <- ttkcheckbutton(frame2, text=txt, variable=show.points.var)
-  txt <- "show arrows"
+  txt <- "show vector arrows"
   frame2.chk.06.1 <- ttkcheckbutton(frame2, text=txt, variable=show.arrows.var)
   txt <- "use uniform arrow lengths"
   frame2.chk.07.1 <- ttkcheckbutton(frame2, text=txt, variable=vuni.var)
-  
+
   txt <- "show tickmarks on second axes"
   frame2.chk.08.1 <- ttkcheckbutton(frame2, text=txt, variable=show.2.axes.var)
   txt <- "add minor tickmarks"
   frame2.chk.09.1 <- ttkcheckbutton(frame2, text=txt, variable=minor.ticks.var)
   txt <- "place tickmarks inside plot region"
   frame2.chk.10.1 <- ttkcheckbutton(frame2, text=txt, variable=ticks.inside.var)
-  
+
   tkgrid(frame2.chk.01.1, pady=1, sticky="w")
   tkgrid(frame2.chk.02.1, pady=1, sticky="w")
   tkgrid(frame2.chk.03.1, pady=1, sticky="w")
@@ -270,23 +270,23 @@ SetConfiguration <- function(parent=NULL) {
   tkgrid(frame2.chk.08.1, pady=1, sticky="w")
   tkgrid(frame2.chk.09.1, pady=1, sticky="w")
   tkgrid(frame2.chk.10.1, pady=1, sticky="w")
-  
+
   # Final layout
-  
+
   tkgrid(frame1, frame2, padx=2, pady=2, sticky="nswe")
   tkgrid.columnconfigure(pw, 0, weight=2)
-  
+
   tkpack(pw, fill="x", expand=TRUE)
-  
+
   # GUI control
-  
+
   tkfocus(tt)
   tkgrab(tt)
   tkbind(tt, "<Destroy>", function() tclvalue(tt.done.var) <- 1)
-  
+
   tclServiceMode(TRUE)
   tkwait.variable(tt.done.var)
-  
+
   tclServiceMode(FALSE)
   tkgrab.release(tt)
   tkdestroy(tt)
